Index: src/compiler/arm64/instruction-selector-arm64.cc |
diff --git a/src/compiler/arm64/instruction-selector-arm64.cc b/src/compiler/arm64/instruction-selector-arm64.cc |
index 29fec34075abae0468719962c1548901e7d6d5a5..1ec5ab4c41a59a08d680582b08e9d4db04dd0e7a 100644 |
--- a/src/compiler/arm64/instruction-selector-arm64.cc |
+++ b/src/compiler/arm64/instruction-selector-arm64.cc |
@@ -1832,12 +1832,12 @@ void InstructionSelector::VisitBranch(Node* branch, BasicBlock* tbranch, |
if (ProjectionIndexOf(value->op()) == 1u) { |
// We cannot combine the <Operation>WithOverflow with this branch |
// unless the 0th projection (the use of the actual value of the |
// <Operation> is either NULL, which means there's no use of the |
// actual value, or was already defined, which means it is scheduled |
// *AFTER* this branch). |
Node* const node = value->InputAt(0); |
Node* const result = NodeProperties::FindProjection(node, 0); |
- if (result == NULL || IsDefined(result)) { |
+ if (result == nullptr || IsDefined(result)) { |
switch (node->opcode()) { |
case IrOpcode::kInt32AddWithOverflow: |
cont.OverwriteAndNegateIfEqual(kOverflow); |
@@ -1832,12 +1832,12 @@ void InstructionSelector::VisitBranch(Node* branch, BasicBlock* tbranch, |
// We cannot combine the <Operation>WithOverflow with this branch |
// unless the 0th projection (the use of the actual value of the |
- // <Operation> is either NULL, which means there's no use of the |
+ // <Operation> is either nullptr, which means there's no use of the |
// actual value, or was already defined, which means it is scheduled |
// *AFTER* this branch). |